Crate solana_tpu_client_next

Crate solana_tpu_client_next 

👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Feature flags

Tpu-client-next supports three features:

  • metrics: Enables implementation of the method report_to_influxdb for SendTransactionStats structure.
  • log: Enables logging using log crate. It is enabled by default.
  • tracing: Enables logging using tracing crate instead of log. This feature is mutually exclusive with log.

Re-exports

pub use crate::connection_workers_scheduler::ConnectionWorkersScheduler;Deprecated
pub use crate::connection_workers_scheduler::ConnectionWorkersSchedulerError;Deprecated
pub use crate::send_transaction_stats::SendTransactionStats;Deprecated

Modules

connection_workers_schedulerDeprecated
This module defines ConnectionWorkersScheduler which sends transactions to the upcoming leaders.
leader_updaterDeprecated
This module provides LeaderUpdater trait along with create_leader_updater function to create an instance of this trait.
send_transaction_statsDeprecated
This module defines SendTransactionStats which is used to collect statistics about relevant network events. This will aggregate events from all transactions and all leaders. Stats can be reset at any time to start a new monitoring period.
transaction_batchDeprecated
This module holds TransactionBatch structure.
workers_cacheDeprecated
This module defines WorkersCache along with aux struct WorkerInfo. These structures provide mechanisms for caching workers, sending transaction batches, and gathering send transaction statistics.