pub enum WorkersCacheError {
ReceiverDropped,
FullChannel,
TaskJoinFailure,
ShutdownError,
WorkerNotFound,
}👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Variants
ReceiverDropped
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.typically happens when the client could not establish the connection.
FullChannel
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.TaskJoinFailure
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.ShutdownError
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.WorkerNotFound
👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Trait Implementations
Sourceimpl Debug for WorkersCacheError
impl Debug for WorkersCacheError
Sourceimpl Display for WorkersCacheError
impl Display for WorkersCacheError
Sourceimpl Error for WorkersCacheError
impl Error for WorkersCacheError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
Sourceimpl From<WorkersCacheError> for ConnectionWorkersSchedulerError
impl From<WorkersCacheError> for ConnectionWorkersSchedulerError
Sourcefn from(source: WorkersCacheError) -> Self
fn from(source: WorkersCacheError) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for WorkersCacheError
impl PartialEq for WorkersCacheError
impl StructuralPartialEq for WorkersCacheError