👎Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Expand description
Feature flags
Tpu-client-next supports three features:
metrics: Enables implementation of the methodreport_to_influxdbforSendTransactionStatsstructure.log: Enables logging usinglogcrate. It is enabled by default.tracing: Enables logging usingtracingcrate instead oflog. This feature is mutually exclusive withlog.
Re-exports
pub use crate::connection_workers_scheduler::ConnectionWorkersScheduler;Deprecated pub use crate::connection_workers_scheduler::ConnectionWorkersSchedulerError;Deprecated pub use crate::send_transaction_stats::SendTransactionStats;Deprecated
Modules
- connection_
workers_ scheduler Deprecated - This module defines
ConnectionWorkersSchedulerwhich sends transactions to the upcoming leaders. - leader_
updater Deprecated - This module provides
LeaderUpdatertrait along withcreate_leader_updaterfunction to create an instance of this trait. - send_
transaction_ stats Deprecated - This module defines
SendTransactionStatswhich is used to collect statistics about relevant network events. This will aggregate events from all transactions and all leaders. Stats can be reset at any time to start a new monitoring period. - transaction_
batch Deprecated - This module holds
TransactionBatchstructure. - workers_
cache Deprecated - This module defines
WorkersCachealong with aux structWorkerInfo. These structures provide mechanisms for caching workers, sending transaction batches, and gathering send transaction statistics.